@@ -122,6 +122,7 @@ index((eval_license), 0, backward_compatibility, backcomp).
 index((trie_insert_new), 3, backward_compatibility, backcomp).
 index((thread_at_exit), 1, backward_compatibility, backcomp).
 index((read_history), 6, backward_compatibility, backcomp).
+index(('$sig_atomic'), 1, backward_compatibility, backcomp).
 index((base32), 2, base32, base32).
 index((base32), 3, base32, base32).
 index((base64_encoded), 3, base64, base64).
@@ -557,6 +558,8 @@ index((subset), 2, lists, lists).
 index((subtract), 3, lists, lists).
 index((main), 0, prolog_main, main).
 index((argv_options), 3, prolog_main, main).
+index((argv_options), 4, prolog_main, main).
+index((argv_usage), 1, prolog_main, main).
 index((cli_parse_debug_options), 2, prolog_main, main).
 index((cli_enable_development_system), 0, prolog_main, main).
 index((make), 0, make, make).
@@ -872,6 +875,7 @@ index((trace), 1, prolog_trace, prolog_trace).
 index((trace), 2, prolog_trace, prolog_trace).
 index((tracing), 2, prolog_trace, prolog_trace).
 index((notraceall), 0, prolog_trace, prolog_trace).
+index((require_prolog_version), 2, prolog_versions, prolog_versions).
 index((wrap_predicate), 4, prolog_wrap, prolog_wrap).
 index((unwrap_predicate), 2, prolog_wrap, prolog_wrap).
 index((current_predicate_wrapper), 4, prolog_wrap, prolog_wrap).
